pub struct BeeData {
pub entity_data: Compound,
pub ticks_in_hive: VarInt,
pub min_ticks_in_hive: VarInt,
}Expand description
Information about a Bee inside a Beehive.
Fields
entity_data: CompoundThe NBT data of the Bee entity itself (Health, Name, etc.).
ticks_in_hive: VarIntHow many ticks the bee has been inside the hive.
min_ticks_in_hive: VarIntThe minimum ticks required before the bee can leave.