pub struct WritablePage {
pub raw: String,
pub filtered: Option<String>,
}Expand description
A page in a Book and Quill (Writable).
Fields
raw: StringThe raw text entered by the player.
filtered: Option<String>If the server runs a chat filter, this is the filtered version. If None, the raw text is considered safe to display.